@@ -38,9 +38,12 @@
     #include "tests/testkget.h"
 #endif
 
+#include "kget_debug.h"
+#include <qdebug.h>
+
 #include <kapplication.h>
 #include <kstandarddirs.h>
-#include <KInputDialog>
+#include <QInputDialog>
 #include <kmessagebox.h>
 #include <knotifyconfigwidget.h>
 #include <kfiledialog.h>
@@ -49,24 +52,27 @@
 #include <kiconloader.h>
 #include <kstandardaction.h>
 #include <klocale.h>
-#include <kicon.h>
+#include <QIcon>
 #include <kactionmenu.h>
 #include <KSelectAction>
-#include <krun.h>
+#include <KRun>
 #include <kicondialog.h>
 #include "core/verifier.h"
 #include <QClipboard>
 #include <QTimer>
-#include <QtTest/QtTest>
+#include <QKeySequence>
+#ifdef DO_KGET_TEST
+    #include <QtTest>
+#endif
 
 MainWindow::MainWindow(bool showMainwindow, bool startWithoutAnimation, bool doTesting, QWidget *parent)
     : KXmlGuiWindow( parent ),
-      m_drop(0),
-      m_dock(0),
-      clipboardTimer(0),
+      m_drop(nullptr),
+      m_dock(nullptr),
+      clipboardTimer(nullptr),
       m_startWithoutAnimation(startWithoutAnimation),
-      m_doTesting(doTesting),
-      m_webinterface(0)
+      m_doTesting(doTesting)/*,
+      m_webinterface(nullptr)*/
 {
     // do not quit the app when it has been minimized to system tray and a new transfer dialog
     // gets opened and closed again.
@@ -106,7 +112,7 @@ MainWindow::~MainWindow()
     // reset konqueror integration (necessary if user enabled / disabled temporarily integration from tray)
     slotKonquerorIntegration( Settings::konquerorIntegration() );
     // the following call saves options set in above dtors
-    Settings::self()->writeConfig();
+    Settings::self()->save();
 
     delete m_drop;
     delete m_kget;
@@ -138,80 +144,80 @@ int MainWindow::transfersPercent()
 
 void MainWindow::setupActions()
 {
-    KAction *newDownloadAction = actionCollection()->addAction("new_download");
+    QAction *newDownloadAction = actionCollection()->addAction("new_download");
     newDownloadAction->setText(i18n("&New Download..."));
-    newDownloadAction->setIcon(KIcon("document-new"));
-    newDownloadAction->setShortcuts(KShortcut("Ctrl+N"));
-    newDownloadAction->setHelpText(i18n("Opens a dialog to add a transfer to the list"));
+    newDownloadAction->setIcon(QIcon::fromTheme("document-new"));
+    //newDownloadAction->setHelpText(i18n("Opens a dialog to add a transfer to the list"));
+    actionCollection()->setDefaultShortcut(newDownloadAction, QKeySequence(Qt::CTRL + Qt::Key_N));
     connect(newDownloadAction, SIGNAL(triggered()), SLOT(slotNewTransfer()));
 
-    KAction *openAction = actionCollection()->addAction("import_transfers");
+    QAction *openAction = actionCollection()->addAction("import_transfers");
     openAction->setText(i18n("&Import Transfers..."));
-    openAction->setIcon(KIcon("document-open"));
-    openAction->setShortcuts(KShortcut("Ctrl+I"));
-    openAction->setHelpText(i18n("Imports a list of transfers"));
+    openAction->setIcon(QIcon::fromTheme("document-open"));
+    //openAction->setHelpText(i18n("Imports a list of transfers"));
+    actionCollection()->setDefaultShortcut(openAction, QKeySequence(Qt::CTRL + Qt::Key_I));
     connect(openAction, SIGNAL(triggered()), SLOT(slotImportTransfers()));
 
-    KAction *exportAction = actionCollection()->addAction("export_transfers");
+    QAction *exportAction = actionCollection()->addAction("export_transfers");
     exportAction->setText(i18n("&Export Transfers List..."));
-    exportAction->setIcon(KIcon("document-export"));
-    exportAction->setShortcuts(KShortcut("Ctrl+E"));
-    exportAction->setHelpText(i18n("Exports the current transfers into a file"));
+    exportAction->setIcon(QIcon::fromTheme("document-export"));
+    //exportAction->setHelpText(i18n("Exports the current transfers into a file"));
+    actionCollection()->setDefaultShortcut(exportAction, QKeySequence(Qt::CTRL + Qt::Key_E));
     connect(exportAction, SIGNAL(triggered()), SLOT(slotExportTransfers()));
 
-    KAction *createMetalinkAction = actionCollection()->addAction("create_metalink");
+    QAction *createMetalinkAction = actionCollection()->addAction("create_metalink");
     createMetalinkAction->setText(i18n("&Create a Metalink..."));
-    createMetalinkAction->setIcon(KIcon("journal-new"));
-    createMetalinkAction->setHelpText(i18n("Creates or modifies a metalink and saves it on disk"));
+    createMetalinkAction->setIcon(QIcon::fromTheme("journal-new"));
+    //createMetalinkAction->setHelpText(i18n("Creates or modifies a metalink and saves it on disk"));
     connect(createMetalinkAction, SIGNAL(triggered()), SLOT(slotCreateMetalink()));
 
-    KAction *priorityTop = actionCollection()->addAction("priority_top");
+    QAction *priorityTop = actionCollection()->addAction("priority_top");
     priorityTop->setText(i18n("Top Priority"));
-    priorityTop->setIcon(KIcon("arrow-up-double"));
-    priorityTop->setShortcuts(KShortcut("Ctrl+PgUp"));
-    priorityTop->setHelpText(i18n("Download selected transfer first"));
+    priorityTop->setIcon(QIcon::fromTheme("arrow-up-double"));
+    //priorityTop->setHelpText(i18n("Download selected transfer first"));
+    actionCollection()->setDefaultShortcut(priorityTop, QKeySequence(Qt::CTRL + Qt::Key_PageUp));
     connect(priorityTop, SIGNAL(triggered()), this, SLOT(slotPriorityTop()));
 
-    KAction *priorityBottom = actionCollection()->addAction("priority_bottom");
+    QAction *priorityBottom = actionCollection()->addAction("priority_bottom");
     priorityBottom->setText(i18n("Least Priority"));
-    priorityBottom->setIcon(KIcon("arrow-down-double"));
-    priorityBottom->setShortcuts(KShortcut("Ctrl+PgDown"));
-    priorityBottom->setHelpText(i18n("Download selected transfer last"));
+    priorityBottom->setIcon(QIcon::fromTheme("arrow-down-double"));
+    //priorityBottom->setHelpText(i18n("Download selected transfer last"));
+    actionCollection()->setDefaultShortcut(priorityBottom, QKeySequence(Qt::CTRL + Qt::Key_PageDown));
     connect(priorityBottom, SIGNAL(triggered()), this, SLOT(slotPriorityBottom()));
 
-    KAction *priorityUp = actionCollection()->addAction("priority_up");
+    QAction *priorityUp = actionCollection()->addAction("priority_up");
     priorityUp->setText(i18n("Increase Priority"));
-    priorityUp->setIcon(KIcon("arrow-up"));
-    priorityUp->setShortcuts(KShortcut("Ctrl+Up"));
-    priorityUp->setHelpText(i18n("Increase priority for selected transfer"));
+    priorityUp->setIcon(QIcon::fromTheme("arrow-up"));
+    //priorityUp->setHelpText(i18n("Increase priority for selected transfer"));
+    actionCollection()->setDefaultShortcut(priorityUp, QKeySequence(Qt::CTRL + Qt::Key_Up));
     connect(priorityUp, SIGNAL(triggered()), this, SLOT(slotPriorityUp()));
 
-    KAction *priorityDown = actionCollection()->addAction("priority_down");
+    QAction *priorityDown = actionCollection()->addAction("priority_down");
     priorityDown->setText(i18n("Decrease Priority"));
-    priorityDown->setIcon(KIcon("arrow-down"));
-    priorityDown->setShortcuts(KShortcut("Ctrl+Down"));
-    priorityDown->setHelpText(i18n("Decrease priority for selected transfer"));
+    priorityDown->setIcon(QIcon::fromTheme("arrow-down"));
+    //priorityDown->setHelpText(i18n("Decrease priority for selected transfer"));
+    actionCollection()->setDefaultShortcut(priorityDown, QKeySequence(Qt::CTRL + Qt::Key_Down));
     connect(priorityDown, SIGNAL(triggered()), this, SLOT(slotPriorityDown()));
 
     //FIXME: Not needed maybe because the normal delete already deletes groups?
-    KAction *deleteGroupAction = actionCollection()->addAction("delete_groups");
+    QAction *deleteGroupAction = actionCollection()->addAction("delete_groups");
     deleteGroupAction->setText(i18n("Delete Group"));
-    deleteGroupAction->setIcon(KIcon("edit-delete"));
-    deleteGroupAction->setHelpText(i18n("Delete selected group"));
+    deleteGroupAction->setIcon(QIcon::fromTheme("edit-delete"));
+    //deleteGroupAction->setHelpText(i18n("Delete selected group"));
     connect(deleteGroupAction, SIGNAL(triggered()), SLOT(slotDeleteGroup()));
 
-    KAction *renameGroupAction = actionCollection()->addAction("rename_groups");
+    QAction *renameGroupAction = actionCollection()->addAction("rename_groups");
     renameGroupAction->setText(i18n("Rename Group..."));
-    renameGroupAction->setIcon(KIcon("edit-rename"));
+    renameGroupAction->setIcon(QIcon::fromTheme("edit-rename"));
     connect(renameGroupAction, SIGNAL(triggered()), SLOT(slotRenameGroup()));
 
-    KAction *setIconGroupAction = actionCollection()->addAction("seticon_groups");
+    QAction *setIconGroupAction = actionCollection()->addAction("seticon_groups");
     setIconGroupAction->setText(i18n("Set Icon..."));
-    setIconGroupAction->setIcon(KIcon("preferences-desktop-icons"));
-    setIconGroupAction->setHelpText(i18n("Select a custom icon for the selected group"));
+    setIconGroupAction->setIcon(QIcon::fromTheme("preferences-desktop-icons"));
+    //setIconGroupAction->setHelpText(i18n("Select a custom icon for the selected group"));
     connect(setIconGroupAction, SIGNAL(triggered()), SLOT(slotSetIconGroup()));
 
-    m_autoPasteAction = new KToggleAction(KIcon("edit-paste"),
+    m_autoPasteAction = new KToggleAction(QIcon::fromTheme("edit-paste"),
                                           i18n("Auto-Paste Mode"), actionCollection());
     actionCollection()->addAction("auto_paste", m_autoPasteAction);
     m_autoPasteAction->setChecked(Settings::autoPaste());
@@ -220,7 +226,7 @@ void MainWindow::setupActions()
                                          "the clipboard for URLs and paste them automatically."));
     connect(m_autoPasteAction, SIGNAL(triggered()), SLOT(slotToggleAutoPaste()));
 
-    m_konquerorIntegration = new KToggleAction(KIcon("konqueror"),
+    m_konquerorIntegration = new KToggleAction(QIcon::fromTheme("konqueror"),
                                                i18n("Use KGet as Konqueror Download Manager"), actionCollection());
     actionCollection()->addAction("konqueror_integration", m_konquerorIntegration);
     connect(m_konquerorIntegration, SIGNAL(triggered(bool)), SLOT(slotTrayKonquerorIntegration(bool)));
@@ -238,57 +244,57 @@ void MainWindow::setupActions()
     // Transfer related actions
     actionCollection()->addAction(KStandardAction::SelectAll, "select_all", m_viewsContainer, SLOT(selectAll()));
 
-    KAction *deleteSelectedAction = actionCollection()->addAction("delete_selected_download");
+    QAction *deleteSelectedAction = actionCollection()->addAction("delete_selected_download");
     deleteSelectedAction->setText(i18nc("delete selected transfer item", "Remove Selected"));
-    deleteSelectedAction->setIcon(KIcon("edit-delete"));
-    deleteSelectedAction->setShortcuts(KShortcut("Del"));
-    deleteSelectedAction->setHelpText(i18n("Removes selected transfer and deletes files from disk if it's not finished"));
+    deleteSelectedAction->setIcon(QIcon::fromTheme("edit-delete"));
+//     deleteSelectedAction->setHelpText(i18n("Removes selected transfer and deletes files from disk if it's not finished"));
+    actionCollection()->setDefaultShortcut(deleteSelectedAction, QKeySequence(Qt::Key_Delete));
     connect(deleteSelectedAction, SIGNAL(triggered()), SLOT(slotDeleteSelected()));
 
-    KAction *deleteAllFinishedAction = actionCollection()->addAction("delete_all_finished");
+    QAction *deleteAllFinishedAction = actionCollection()->addAction("delete_all_finished");
     deleteAllFinishedAction->setText(i18nc("delete all finished transfers", "Remove All Finished"));
-    deleteAllFinishedAction->setIcon(KIcon("edit-clear-list"));
-    deleteAllFinishedAction->setHelpText(i18n("Removes all finished transfers and leaves all files on disk"));
+    deleteAllFinishedAction->setIcon(QIcon::fromTheme("edit-clear-list"));
+//     deleteAllFinishedAction->setHelpText(i18n("Removes all finished transfers and leaves all files on disk"));
     connect(deleteAllFinishedAction, SIGNAL(triggered()), SLOT(slotDeleteFinished()));
     
-    KAction *deleteSelectedIncludingFilesAction = actionCollection()->addAction("delete_selected_download_including_files");
+    QAction *deleteSelectedIncludingFilesAction = actionCollection()->addAction("delete_selected_download_including_files");
     deleteSelectedIncludingFilesAction->setText(i18nc("delete selected transfer item and files", "Remove Selected and Delete Files"));
-    deleteSelectedIncludingFilesAction->setIcon(KIcon("edit-delete"));
-    deleteSelectedIncludingFilesAction->setHelpText(i18n("Removes selected transfer and deletes files from disk in any case"));
+    deleteSelectedIncludingFilesAction->setIcon(QIcon::fromTheme("edit-delete"));
+//     deleteSelectedIncludingFilesAction->setHelpText(i18n("Removes selected transfer and deletes files from disk in any case"));
     connect(deleteSelectedIncludingFilesAction, SIGNAL(triggered()), SLOT(slotDeleteSelectedIncludingFiles()));
 
-    KAction *redownloadSelectedAction = actionCollection()->addAction("redownload_selected_download");
+    QAction *redownloadSelectedAction = actionCollection()->addAction("redownload_selected_download");
     redownloadSelectedAction->setText(i18nc("redownload selected transfer item", "Redownload Selected"));
-    redownloadSelectedAction->setIcon(KIcon("view-refresh"));
+    redownloadSelectedAction->setIcon(QIcon::fromTheme("view-refresh"));
     connect(redownloadSelectedAction, SIGNAL(triggered()), SLOT(slotRedownloadSelected()));
 
-    KAction *startAllAction = actionCollection()->addAction("start_all_download");
+    QAction *startAllAction = actionCollection()->addAction("start_all_download");
     startAllAction->setText(i18n("Start All"));
-    startAllAction->setIcon(KIcon("media-seek-forward"));
-    startAllAction->setShortcuts(KShortcut("Ctrl+R"));
-    startAllAction->setHelpText(i18n("Starts / resumes all transfers"));
+    startAllAction->setIcon(QIcon::fromTheme("media-seek-forward"));
+//     startAllAction->setHelpText(i18n("Starts / resumes all transfers"));
+    actionCollection()->setDefaultShortcut(startAllAction, QKeySequence(Qt::CTRL + Qt::Key_R));
     connect(startAllAction, SIGNAL(triggered()), SLOT(slotStartAllDownload()));
 
-    KAction *startSelectedAction = actionCollection()->addAction("start_selected_download");
+    QAction *startSelectedAction = actionCollection()->addAction("start_selected_download");
     startSelectedAction->setText(i18n("Start Selected"));
-    startSelectedAction->setIcon(KIcon("media-playback-start"));
-    startSelectedAction->setHelpText(i18n("Starts / resumes selected transfer"));
+    startSelectedAction->setIcon(QIcon::fromTheme("media-playback-start"));
+//     startSelectedAction->setHelpText(i18n("Starts / resumes selected transfer"));
     connect(startSelectedAction, SIGNAL(triggered()), SLOT(slotStartSelectedDownload()));
 
-    KAction *stopAllAction = actionCollection()->addAction("stop_all_download");
+    QAction *stopAllAction = actionCollection()->addAction("stop_all_download");
     stopAllAction->setText(i18n("Pause All"));
-    stopAllAction->setIcon(KIcon("media-playback-pause"));
-    stopAllAction->setShortcuts(KShortcut("Ctrl+P"));
-    stopAllAction->setHelpText(i18n("Pauses all transfers"));
+    stopAllAction->setIcon(QIcon::fromTheme("media-playback-pause"));
+//     stopAllAction->setHelpText(i18n("Pauses all transfers"));
+    actionCollection()->setDefaultShortcut(stopAllAction, QKeySequence(Qt::CTRL + Qt::Key_P));
     connect(stopAllAction, SIGNAL(triggered()), SLOT(slotStopAllDownload()));
 
-    KAction *stopSelectedAction = actionCollection()->addAction("stop_selected_download");
+    QAction *stopSelectedAction = actionCollection()->addAction("stop_selected_download");
     stopSelectedAction->setText(i18n("Stop Selected"));
-    stopSelectedAction->setIcon(KIcon("media-playback-pause"));
-    stopSelectedAction->setHelpText(i18n("Pauses selected transfer"));
+    stopSelectedAction->setIcon(QIcon::fromTheme("media-playback-pause"));
+    //stopSelectedAction->setHelpText(i18n("Pauses selected transfer"));
     connect(stopSelectedAction, SIGNAL(triggered()), SLOT(slotStopSelectedDownload()));
 
-    KActionMenu *startActionMenu = new KActionMenu(KIcon("media-playback-start"), i18n("Start"),
+    KActionMenu *startActionMenu = new KActionMenu(QIcon::fromTheme("media-playback-start"), i18n("Start"),
                                                      actionCollection());
     actionCollection()->addAction("start_menu", startActionMenu);
     startActionMenu->setDelayed(true);
@@ -296,7 +302,7 @@ void MainWindow::setupActions()
     startActionMenu->addAction(startAllAction);
     connect(startActionMenu, SIGNAL(triggered()), SLOT(slotStartDownload()));
 
-    KActionMenu *stopActionMenu = new KActionMenu(KIcon("media-playback-pause"), i18n("Pause"),
+    KActionMenu *stopActionMenu = new KActionMenu(QIcon::fromTheme("media-playback-pause"), i18n("Pause"),
                                                     actionCollection());
     actionCollection()->addAction("stop_menu", stopActionMenu);
     stopActionMenu->setDelayed(true);
@@ -304,75 +310,75 @@ void MainWindow::setupActions()
     stopActionMenu->addAction(stopAllAction);
     connect(stopActionMenu, SIGNAL(triggered()), SLOT(slotStopDownload()));
     
-    KAction *openDestAction = actionCollection()->addAction("transfer_open_dest");
+    QAction *openDestAction = actionCollection()->addAction("transfer_open_dest");
     openDestAction->setText(i18n("Open Destination"));
-    openDestAction->setIcon(KIcon("document-open"));
+    openDestAction->setIcon(QIcon::fromTheme("document-open"));
     connect(openDestAction, SIGNAL(triggered()), SLOT(slotTransfersOpenDest()));
 
-    KAction *openFileAction = actionCollection()->addAction("transfer_open_file");
+    QAction *openFileAction = actionCollection()->addAction("transfer_open_file");
     openFileAction->setText(i18n("Open File"));
-    openFileAction->setIcon(KIcon("document-open"));
+    openFileAction->setIcon(QIcon::fromTheme("document-open"));
     connect(openFileAction, SIGNAL(triggered()), SLOT(slotTransfersOpenFile()));
 
-    KAction *showDetailsAction = new KToggleAction(KIcon("document-properties"), i18n("Show Details"), actionCollection());
+    QAction *showDetailsAction = new KToggleAction(QIcon::fromTheme("document-properties"), i18n("Show Details"), actionCollection());
     actionCollection()->addAction("transfer_show_details", showDetailsAction);
     connect(showDetailsAction, SIGNAL(triggered()), SLOT(slotTransfersShowDetails()));
 
-    KAction *copyUrlAction = actionCollection()->addAction("transfer_copy_source_url");
+    QAction *copyUrlAction = actionCollection()->addAction("transfer_copy_source_url");
     copyUrlAction->setText(i18n("Copy URL to Clipboard"));
-    copyUrlAction->setIcon(KIcon("edit-copy"));
+    copyUrlAction->setIcon(QIcon::fromTheme("edit-copy"));
     connect(copyUrlAction, SIGNAL(triggered()), SLOT(slotTransfersCopySourceUrl()));
 
-    KAction *transferHistoryAction = actionCollection()->addAction("transfer_history");
+    QAction *transferHistoryAction = actionCollection()->addAction("transfer_history");
     transferHistoryAction->setText(i18n("&Transfer History"));
-    transferHistoryAction->setIcon(KIcon("view-history"));
-    transferHistoryAction->setShortcuts(KShortcut("Ctrl+H"));
+    transferHistoryAction->setIcon(QIcon::fromTheme("view-history"));
+    actionCollection()->setDefaultShortcut(transferHistoryAction, QKeySequence(Qt::CTRL + Qt::Key_H));
     connect(transferHistoryAction, SIGNAL(triggered()), SLOT(slotTransferHistory()));
 
-    KAction *transferGroupSettingsAction = actionCollection()->addAction("transfer_group_settings");
+    QAction *transferGroupSettingsAction = actionCollection()->addAction("transfer_group_settings");
     transferGroupSettingsAction->setText(i18n("&Group Settings"));
-    transferGroupSettingsAction->setIcon(KIcon("preferences-system"));
-    transferGroupSettingsAction->setShortcuts(KShortcut("Ctrl+G"));
+    transferGroupSettingsAction->setIcon(QIcon::fromTheme("preferences-system"));
+    actionCollection()->setDefaultShortcut(transferGroupSettingsAction, QKeySequence(Qt::CTRL + Qt::Key_G));
     connect(transferGroupSettingsAction, SIGNAL(triggered()), SLOT(slotTransferGroupSettings()));
 
-    KAction *transferSettingsAction = actionCollection()->addAction("transfer_settings");
+    QAction *transferSettingsAction = actionCollection()->addAction("transfer_settings");
     transferSettingsAction->setText(i18n("&Transfer Settings"));
-    transferSettingsAction->setIcon(KIcon("preferences-system"));
-    transferSettingsAction->setShortcuts(KShortcut("Ctrl+T"));
+    transferSettingsAction->setIcon(QIcon::fromTheme("preferences-system"));
+    actionCollection()->setDefaultShortcut(transferSettingsAction, QKeySequence(Qt::CTRL + Qt::Key_T));
     connect(transferSettingsAction, SIGNAL(triggered()), SLOT(slotTransferSettings()));
 
-    KAction *listLinksAction = actionCollection()->addAction("import_links");
+    QAction *listLinksAction = actionCollection()->addAction("import_links");
     listLinksAction->setText(i18n("Import &Links..."));
-    listLinksAction->setIcon(KIcon("view-list-text"));
-    listLinksAction->setShortcuts(KShortcut("Ctrl+L"));
+    listLinksAction->setIcon(QIcon::fromTheme("view-list-text"));
+    actionCollection()->setDefaultShortcut(listLinksAction, QKeySequence(Qt::CTRL + Qt::Key_L));
     connect(listLinksAction, SIGNAL(triggered()), SLOT(slotShowListLinks()));
 
     //create the download finished actions which can be displayed in the toolbar
     KSelectAction *downloadFinishedActions = new KSelectAction(i18n("After downloads finished action"), this);//TODO maybe with name??
     actionCollection()->addAction("download_finished_actions", downloadFinishedActions);
-    downloadFinishedActions->setHelpText(i18n("Choose an action that is executed after all downloads have been finished."));
+    //downloadFinishedActions->setHelpText(i18n("Choose an action that is executed after all downloads have been finished."));
 
-    KAction *noAction = downloadFinishedActions->addAction(i18n("No Action"));
+    QAction *noAction = downloadFinishedActions->addAction(i18n("No Action"));
     connect(noAction, SIGNAL(triggered()), SLOT(slotDownloadFinishedActions()));
     downloadFinishedActions->addAction(noAction);
 
-    KAction *quitAction = downloadFinishedActions->addAction(i18n("Quit KGet"));
+    QAction *quitAction = downloadFinishedActions->addAction(i18n("Quit KGet"));
     quitAction->setData(KGet::Quit);
     connect(quitAction, SIGNAL(triggered()), SLOT(slotDownloadFinishedActions()));
     downloadFinishedActions->addAction(quitAction);
 
 #ifdef HAVE_KWORKSPACE
-    KAction *shutdownAction = downloadFinishedActions->addAction(i18n("Turn Off Computer"));
+    QAction *shutdownAction = downloadFinishedActions->addAction(i18n("Turn Off Computer"));
     shutdownAction->setData(KGet::Shutdown);
     connect(shutdownAction, SIGNAL(triggered()), SLOT(slotDownloadFinishedActions()));
     downloadFinishedActions->addAction(shutdownAction);
 
-    KAction *hibernateAction = downloadFinishedActions->addAction(i18n("Hibernate Computer"));
+    QAction *hibernateAction = downloadFinishedActions->addAction(i18n("Hibernate Computer"));
     hibernateAction->setData(KGet::Hibernate);
     connect(hibernateAction, SIGNAL(triggered()), SLOT(slotDownloadFinishedActions()));
     downloadFinishedActions->addAction(hibernateAction);
 
-    KAction *suspendAction = downloadFinishedActions->addAction(i18n("Suspend Computer"));
+    QAction *suspendAction = downloadFinishedActions->addAction(i18n("Suspend Computer"));
     suspendAction->setData(KGet::Suspend);
     connect(suspendAction, SIGNAL(triggered()), SLOT(slotDownloadFinishedActions()));
     downloadFinishedActions->addAction(suspendAction);
@@ -387,7 +393,7 @@ void MainWindow::setupActions()
 
 void MainWindow::slotDownloadFinishedActions()
 {
-    KAction *action = static_cast<KAction*>(QObject::sender());
+    QAction *action = static_cast<QAction*>(QObject::sender());
     bool ok;
     const int type = action->data().toInt(&ok);
     if (ok) {
@@ -396,7 +402,7 @@ void MainWindow::slotDownloadFinishedActions()
 
     //only after finish actions have a number assigned
     Settings::self()->setAfterFinishActionEnabled(ok);
-    Settings::self()->writeConfig();
+    Settings::self()->save();
     slotNewConfig();
 }
 
@@ -453,8 +459,8 @@ void MainWindow::init()
     if ( Settings::autoPaste() )
         clipboardTimer->start(1000);
 
-    if (Settings::webinterfaceEnabled())
-        m_webinterface = new HttpServer(this);
+    /*if (Settings::webinterfaceEnabled())
+        m_webinterface = new HttpServer(this);*///TODO: Port to KF5
 
     if (Settings::speedLimit())
     {
@@ -491,12 +497,12 @@ void MainWindow::slotToggleDropTarget()
 
 void MainWindow::slotNewTransfer()
 {
-    NewTransferDialogHandler::showNewTransferDialog(KUrl());
+    NewTransferDialogHandler::showNewTransferDialog(QUrl());
 }
 
 void MainWindow::slotImportTransfers()
 {
-    QString filename = KFileDialog::getOpenFileName(KUrl(),
+    QString filename = KFileDialog::getOpenFileName(QUrl(),
                                                     "*.kgt *.metalink *.meta4 *.torrent|" + i18n("All Openable Files") +
                                                     " (*.kgt *.metalink *.meta4 *.torrent)", this, i18n("Open File"));
 
@@ -507,7 +513,7 @@ void MainWindow::slotImportTransfers()
     }
 
     if(!filename.isEmpty())
-        KGet::addTransfer( KUrl( filename ) );
+        KGet::addTransfer( QUrl( filename ) );
 }
 
 void MainWindow::slotUpdateTitlePercent()
@@ -538,7 +544,7 @@ void MainWindow::slotTransfersChanged(QMap<TransferHandler*, Transfer::ChangesFl
             break;
         }
         
-//         kDebug(5001) << it.key() << ": " << it.value() << endl;
+//         qCDebug(KGET_DEBUG) << it.key() << ": " << it.value() << endl;
     }
     
     if (update)
@@ -572,7 +578,7 @@ void MainWindow::slotQuit()
             return;
     }
 
-    Settings::self()->writeConfig();
+    Settings::self()->save();
     qApp->quit();
 }
 
@@ -592,14 +598,14 @@ void MainWindow::slotPreferences()
 void MainWindow::slotExportTransfers()
 {
     const QString filename = KFileDialog::getSaveFileName
-        (KUrl(),
+        (QUrl(),
          "*.kgt|" + i18n("KGet Transfer List") + " (*.kgt)\n*.txt|" + i18n("Text File") + " (*.txt)",
          this,
          i18n("Export Transfers")
         );
 
     if (!filename.isEmpty()) {
-        const bool plain = !filename.endsWith("kgt");
+        const bool plain = !filename.endsWith(QLatin1String(".kgt"));
         KGet::save(filename, plain);
     }
 }
@@ -626,8 +632,8 @@ void MainWindow::slotRenameGroup()
 
     foreach(TransferGroupHandler * it, KGet::selectedTransferGroups())
     {
-        groupName = KInputDialog::getText(i18n("Enter Group Name"),
-                                          i18n("Group name:"), it->name(), &ok, this);
+        groupName = QInputDialog::getText(this, i18n("Enter Group Name"),
+                                          i18n("Group name:"), QLineEdit::Normal, it->name(), &ok);
         if(ok)
             it->setName(groupName);
     }
@@ -691,7 +697,7 @@ void MainWindow::slotStopAllDownload()
     KGet::setSchedulerRunning(false);
     
     // This line ensures that each transfer is stopped. In the handler class
-    // the policy of the transfer will be correctly setted to None
+    // the policy of the transfer will be correctly set to None
     foreach (TransferHandler * it, KGet::allTransfers())
         it->stop();
 }
@@ -770,8 +776,8 @@ void MainWindow::slotRedownloadSelected()
 void MainWindow::slotPriorityTop()
 {
     QList<TransferHandler*> selected = KGet::selectedTransfers();
-    TransferHandler *after = 0;
-    TransferGroupHandler *group = 0;
+    TransferHandler *after = nullptr;
+    TransferGroupHandler *group = nullptr;
     foreach (TransferHandler *transfer, selected) {
         if (!transfer) {
             continue;
@@ -779,7 +785,7 @@ void MainWindow::slotPriorityTop()
 
         //previous transfer was not of the same group, so after has to be reset as the group
         if (!group || (group != transfer->group())) {
-            after = 0;
+            after = nullptr;
             group = transfer->group();
         }
         KGet::model()->moveTransfer(transfer, group, after);
@@ -791,8 +797,8 @@ void MainWindow::slotPriorityBottom()
 {
     QList<TransferHandler*> selected = KGet::selectedTransfers();
     QList<TransferHandler*> groupTransfers;
-    TransferHandler *after = 0;
-    TransferGroupHandler *group = 0;
+    TransferHandler *after = nullptr;
+    TransferGroupHandler *group = nullptr;
     foreach (TransferHandler *transfer, selected) {
         if (!transfer) {
             continue;
@@ -803,7 +809,7 @@ void MainWindow::slotPriorityBottom()
             group = transfer->group();
             groupTransfers = group->transfers();
             if (groupTransfers.isEmpty()) {
-                after = 0;
+                after = nullptr;
             } else {
                 after = groupTransfers.last();
             }
@@ -818,9 +824,9 @@ void MainWindow::slotPriorityUp()
 {
     QList<TransferHandler*> selected = KGet::selectedTransfers();
     QList<TransferHandler*> groupTransfers;
-    TransferHandler *after = 0;
+    TransferHandler *after = nullptr;
     int newIndex = -1;
-    TransferGroupHandler *group = 0;
+    TransferGroupHandler *group = nullptr;
     foreach (TransferHandler *transfer, selected) {
         if (!transfer) {
             continue;
@@ -832,7 +838,7 @@ void MainWindow::slotPriorityUp()
             groupTransfers = group->transfers();
         }
 
-        after = 0;
+        after = nullptr;
         if (!groupTransfers.isEmpty()) {
             int index = groupTransfers.indexOf(transfer);
 
@@ -845,7 +851,7 @@ void MainWindow::slotPriorityUp()
                         after = groupTransfers[newIndex - 1];
                     }
 
-                    //keep the list with the actual movements synchronised
+                    //keep the list with the actual movements synchronized
                     groupTransfers.move(index, newIndex);
 
                     KGet::model()->moveTransfer(transfer, group, after);
@@ -864,7 +870,7 @@ void MainWindow::slotPriorityDown()
     QList<TransferHandler*> selected = KGet::selectedTransfers();
     QList<TransferHandler*> groupTransfers;
     int newIndex = -1;
-    TransferGroupHandler *group = 0;
+    TransferGroupHandler *group = nullptr;
     for (int i = selected.count() - 1; i >= 0; --i) {
         TransferHandler *transfer = selected[i];
         if (!transfer) {
@@ -888,7 +894,7 @@ void MainWindow::slotPriorityDown()
                     TransferHandler *after = groupTransfers[newIndex];
 
 
-                    //keep the list with the actual movements synchronised
+                    //keep the list with the actual movements synchronized
                     groupTransfers.move(index, newIndex);
 
                     KGet::model()->moveTransfer(transfer, group, after);
@@ -907,10 +913,10 @@ void MainWindow::slotTransfersOpenDest()
     QStringList openedDirs;
     foreach(TransferHandler * it, KGet::selectedTransfers())
     {
-        QString directory = it->dest().directory();
+        QString directory = it->dest().adjusted(QUrl::RemoveFilename).toString();
         if( !openedDirs.contains( directory ) )
         {
-            new KRun(directory, this, 0, true, false);
+            new KRun(QUrl(directory), this);
             openedDirs.append( directory );
         }
     }
@@ -920,7 +926,7 @@ void MainWindow::slotTransfersOpenFile()
 {
     foreach(TransferHandler * it, KGet::selectedTransfers())
     {
-        new KRun(it->dest(), this, 0, true, false);
+        new KRun(it->dest(), this);
     }
 }
 
@@ -962,7 +968,7 @@ void MainWindow::slotSaveMyself()
     // save last parameters ..
     Settings::setMainPosition( pos() );
     // .. and write config to disk
-    Settings::self()->writeConfig();
+    Settings::self()->save();
 }
 
 void MainWindow::slotNewToolbarConfig()
@@ -984,7 +990,7 @@ void MainWindow::slotNewConfig()
     } else if (!Settings::enableSystemTray() && m_dock) {
         setVisible(true);
         delete m_dock;
-        m_dock = 0;
+        m_dock = nullptr;
     }
 
     slotKonquerorIntegration(Settings::konquerorIntegration());
@@ -998,14 +1004,14 @@ void MainWindow::slotNewConfig()
     }
     m_autoPasteAction->setChecked(Settings::autoPaste());
 
-    if (Settings::webinterfaceEnabled() && !m_webinterface) {
+    /*if (Settings::webinterfaceEnabled() && !m_webinterface) {
         m_webinterface = new HttpServer(this);
     } else if (m_webinterface && !Settings::webinterfaceEnabled()) {
         delete m_webinterface;
-        m_webinterface = 0;
+        m_webinterface = nullptr;
     } else if (m_webinterface) {
         m_webinterface->settingsChanged();
-    }
+    }*///TODO: Port to KF5
 
     if (Settings::speedLimit())
     {
@@ -1042,8 +1048,8 @@ void MainWindow::slotCheckClipboard()
         if (lastClipboard.isEmpty())
             return;
 
-        const KUrl url = KUrl(lastClipboard);
-        if (url.isValid() && !url.protocol().isEmpty() && url.hasPath() && url.hasHost() && !url.isLocalFile()) {
+        const QUrl url = QUrl(lastClipboard);
+        if (url.isValid() && !url.scheme().isEmpty() && !url.path().isEmpty() && !url.host().isEmpty() && !url.isLocalFile()) {
             bool add = false;
             const QString urlString = url.url();
 
@@ -1105,7 +1111,7 @@ void MainWindow::slotShowMenubar()
 
 void MainWindow::setSystemTrayDownloading(bool running)
 {
-    kDebug(5001);
+    qCDebug(KGET_DEBUG);
 
     if (m_dock)
         m_dock->setDownloading(running);
@@ -1119,7 +1125,7 @@ void MainWindow::slotTransferHistory()
 
 void MainWindow::slotTransferGroupSettings()
 {
-    kDebug(5001);
+    qCDebug(KGET_DEBUG);
     QList<TransferGroupHandler*> list = KGet::selectedTransferGroups();
     foreach(TransferGroupHandler* group, list)
     {
@@ -1131,7 +1137,7 @@ void MainWindow::slotTransferGroupSettings()
 
 void MainWindow::slotTransferSettings()
 {
-    kDebug(5001);
+    qCDebug(KGET_DEBUG);
     QList<TransferHandler*> list = KGet::selectedTransfers();
     foreach(TransferHandler* transfer, list)
     {
@@ -1182,21 +1188,20 @@ void MainWindow::showEvent(QShowEvent *)
 
 void MainWindow::dragEnterEvent(QDragEnterEvent * event)
 {
-    event->setAccepted(KUrl::List::canDecode(event->mimeData())
-                  || event->mimeData()->hasText());
+    event->setAccepted(event->mimeData()->hasUrls());
 }
 
 void MainWindow::dropEvent(QDropEvent * event)
 {
-    KUrl::List list = KUrl::List::fromMimeData(event->mimeData());
+    QList<QUrl> list = event->mimeData()->urls();
 
     if (!list.isEmpty())
     {
         if (list.count() == 1 && list.first().url().endsWith(QLatin1String(".kgt")))
         {
             int msgBoxResult = KMessageBox::questionYesNoCancel(this, i18n("The dropped file is a KGet Transfer List"), "KGet",
-                                   KGuiItem(i18n("&Download"), KIcon("document-save")), 
-                                       KGuiItem(i18n("&Load transfer list"), KIcon("list-add")), KStandardGuiItem::cancel());
+                                   KGuiItem(i18n("&Download"), QIcon::fromTheme("document-save")), 
+                                       KGuiItem(i18n("&Load transfer list"), QIcon::fromTheme("list-add")), KStandardGuiItem::cancel());
 
             if (msgBoxResult == 3) //Download
                 NewTransferDialogHandler::showNewTransferDialog(list.first().url());
@@ -1213,8 +1218,8 @@ void MainWindow::dropEvent(QDropEvent * event)
     }
     else
     {
-        NewTransferDialogHandler::showNewTransferDialog(KUrl());
+        NewTransferDialogHandler::showNewTransferDialog(QUrl());
     }
 }
 
-#include "mainwindow.moc"
+
